@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: tests.sh,v 1.59 2007/02/02 02:02:08 gilles Exp gilles $	
+# $Id: tests.sh,v 1.69 2007/12/31 13:38:37 gilles Exp gilles $	
 
 #### Shell pragmas
 
@@ -26,9 +26,9 @@ run_test() {
 }
 
 run_tests() {
-	for t in $*; do
+	for t in "$@"; do
 		test_count=`expr 1 + $test_count`
-		run_test $t
+		run_test "$t"
 		sleep 1
 	done
 }
@@ -71,16 +71,43 @@ no_args() {
 #                          dprof()
 
 sendtestmessage() {
+    email=${1:-"tata@est.belle"}
     rand=`pwgen 16 1`
     mess='test:'$rand
-    cmd="echo $mess""| mail -s ""$mess"" tata@est.belle"
+    cmd="echo $mess""| mail -s ""$mess"" $email"
     echo $cmd
     eval "$cmd"
 }
 
 
+zzzz() {
+	$CMD_PERL -V
+
+}
+
+option_version() {
+	$CMD_PERL ./imapsync --version
+}
+
+
+option_tests() {
+	$CMD_PERL ./imapsync --tests
+}
+
+
+first_sync_dry() {
+	$CMD_PERL ./imapsync \
+	    --host1 localhost --user1 toto@est.belle \
+	    --passfile1 /var/tmp/secret1 \
+	    --host2 localhost --user2 titi@est.belle \
+	    --passfile2 /var/tmp/secret.titi \
+	    --noauthmd5 --dry
+}
+
+
+
 first_sync() {
-	./imapsync \
+	$CMD_PERL ./imapsync \
 	    --host1 localhost --user1 toto@est.belle \
 	    --passfile1 /var/tmp/secret1 \
 	    --host2 localhost --user2 titi@est.belle \
@@ -93,7 +120,7 @@ locallocal() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
 		sendtestmessage
-		./imapsync \
+		$CMD_PERL  ./imapsync \
 		--host1 localhost --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -108,7 +135,7 @@ locallocal() {
 ll_folder() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
-		./imapsync \
+		$CMD_PERL ./imapsync \
 		--host1 localhost  --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -122,7 +149,7 @@ ll_folder() {
 ll_folderrec() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
-		./imapsync \
+		$CMD_PERL ./imapsync \
 		--host1 localhost  --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -138,7 +165,7 @@ ll_folderrec() {
 ll_buffersize() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
-		./imapsync \
+		$CMD_PERL ./imapsync \
 		--host1 localhost  --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -154,7 +181,7 @@ ll_buffersize() {
 ll_justfolders() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
-		./imapsync \
+		$CMD_PERL ./imapsync \
 		--host1 localhost  --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -169,7 +196,7 @@ ll_justfolders() {
 ll_prefix12() {
 	if test X`hostname` = X"plume"; then
 		echo3 Here is plume
-		./imapsync \
+		$CMD_PERL ./imapsync \
 		--host1 localhost  --user1 tata@est.belle \
 		--passfile1 /var/tmp/secret.tata \
 		--host2 localhost --user2 titi@est.belle \
@@ -393,6 +420,24 @@ ll_include()
 	fi
 }
 
+ll_exclude() 
+{
+	sendtestmessage
+	if test X`hostname` = X"plume"; then
+		echo3 Here is plume
+		./imapsync \
+		--host1 localhost --user1 tata@est.belle \
+		--passfile1 /var/tmp/secret.tata \
+		--host2 localhost --user2 titi@est.belle \
+		--passfile2 /var/tmp/secret.titi \
+		--exclude '^INBOX.yop'
+	else
+		:
+	fi
+}
+
+
+
 ll_regextrans2() 
 {
 	sendtestmessage
@@ -445,6 +490,16 @@ ll_bad_host()
    
 }
 
+ll_bad_host_ssl()
+{
+    ! ./imapsync \
+	--host1 badhost --user1 toto@est.belle \
+	--passfile1 /var/tmp/secret1 \
+	--host2 badhost --user2 titi@est.belle \
+	--passfile2 /var/tmp/secret2 \
+        --ssl1 --ssl2
+}
+
 
 ll_justfoldersizes()
 {
@@ -647,6 +702,13 @@ ll_bigmail() {
 }
 
 
+msw() {
+	sendtestmessage toto@est.belle
+	scp imapsync  Admin@192.168.68.77:'C:/msys/1.0/home/Admin/imapsync/imapsync'
+	ssh Admin@192.168.68.77 'C:/msys/1.0/home/Admin/imapsync/test.bat'
+}
+
+
 ##########################
 # specific tests
 ##########################
@@ -801,6 +863,62 @@ perl -I bugs/lib ./imapsync \
 	
 }
 
+mailenable() {
+	./imapsync \
+	    --user1 imapsync@damashekconsulting.com \
+	    --host1  imap.damashekconsulting.com  \
+	    --passfile1 /var/tmp/secret.damashek \
+	    --sep1 "." --prefix1 "" \
+	    --host2 localhost --user2 toto@est.belle \
+	    --passfile2 /var/tmp/secret1 \
+	    --noauthmd5
+}
+
+ariasolutions() {
+	./imapsync \
+	--host1 209.17.174.20 \
+	--user1 chrisw@canadapack.com \
+	--passfile1 /var/tmp/secret.ariasolutions \
+	--host2 209.17.174.20 \
+	--user2 chrisw@canadapack.com \
+	--passfile2 /var/tmp/secret.ariasolutions \
+	--dry --noauthmd5 --justfoldersizes
+
+	./imapsync \
+	--host1 209.17.174.20 \
+	--user1 test@domain.local \
+	--passfile1 /var/tmp/secret.ariasolutions \
+	--host2 209.17.174.20 \
+	--user2 test@domain.local \
+	--passfile2 /var/tmp/secret.ariasolutions \
+	--dry --noauthmd5 --ssl1
+
+# hang after auth failure 
+	./imapsync \
+	--host1 209.17.174.20 \
+	--user1 test@domain.local \
+	--passfile1 /var/tmp/secret.ariasolutions \
+	--host2 209.17.174.20 \
+	--user2 test@domain.local \
+	--passfile2 /var/tmp/secret.ariasolutions \
+	--dry --debug --debugimap
+
+}
+
+
+ariasolutions2() {
+	./imapsync \
+	--host1 209.17.174.12 \
+	--user1 chrisw@basebuilding.net \
+	--passfile1 /var/tmp/secret.ariasolutions2 \
+	--host2 209.17.174.20 \
+	--user2 chrisw@basebuilding.net\
+	--passfile2 /var/tmp/secret.ariasolutions2 \
+	--noauthmd5 --syncinternaldates
+	# --dry --debug --debugimap
+
+
+}
 ##########################
 ##########################
 
@@ -818,6 +936,8 @@ run_tests perl_syntax
 
 test $# -eq 0 && run_tests \
 	no_args \
+        option_version \
+	option_tests \
 	first_sync \
 	locallocal \
 	ll_folder \
@@ -837,10 +957,12 @@ test $# -eq 0 && run_tests \
 	ll_skipsize \
 	ll_skipheader \
 	ll_include \
+	ll_exclude \
 	ll_regextrans2 \
 	ll_sep2 \
 	ll_bad_login \
 	ll_bad_host \
+	ll_bad_host_ssl \
 	ll_justfoldersizes \
 	ll_useheader \
 	ll_regexmess \
@@ -853,13 +975,14 @@ test $# -eq 0 && run_tests \
 	ll_authuser \
 	ll_delete2 \
 	ll_folderrec \
-	ll_bigmail
+	ll_bigmail \
+	msw
 
 
 
 # selective tests
 
-test $# -gt 0 && run_tests $*
+test $# -gt 0 && run_tests "$@"
 
 # If there, all is good
 
